@@ -19,14 +19,8 @@ impl Application {
 }
 
 impl wita::EventHandler for Application {
-    fn mouse_input(
-        &mut self,
-        _: &wita::Window,
-        button: wita::MouseButton,
-        button_state: wita::KeyState,
-        _: wita::MouseState,
-    ) {
-        if button == wita::MouseButton::Left && button_state == wita::KeyState::Pressed {
+    fn mouse_input(&mut self, ev: wita::event::MouseInput) {
+        if ev.button == wita::MouseButton::Left && ev.button_state == wita::KeyState::Pressed {
             self.count += 1;
             println!("count = {}", self.count);
         }
