@@ -8,22 +8,16 @@ impl Application {
 }
 
 impl wita::EventHandler for Application {
-    fn key_input(
-        &mut self,
-        window: &wita::Window,
-        key_code: wita::KeyCode,
-        state: wita::KeyState,
-        _prev_pressed: bool,
-    ) {
-        if state == wita::KeyState::Pressed {
-            let cursor = match key_code.vkey {
+    fn key_input(&mut self, ev: wita::event::KeyInput) {
+        if ev.state == wita::KeyState::Pressed {
+            let cursor = match ev.key_code.vkey {
                 wita::VirtualKey::Char('D') => wita::Cursor::Arrow,
                 wita::VirtualKey::Char('H') => wita::Cursor::Hand,
                 wita::VirtualKey::Char('I') => wita::Cursor::IBeam,
                 wita::VirtualKey::Char('W') => wita::Cursor::Wait,
                 _ => return,
             };
-            window.set_cursor(cursor);
+            ev.window.set_cursor(cursor);
         }
     }
 }
