@@ -10,8 +10,8 @@ impl Application {
 }
 
 impl wita::EventHandler for Application {
-    fn key_input(&mut self, _: &wita::Window, _: wita::KeyCode, state: wita::KeyState, _: bool) {
-        if state == wita::KeyState::Pressed {
+    fn key_input(&mut self, ev: wita::event::KeyInput) {
+        if ev.state == wita::KeyState::Pressed {
             let mut ks = vec![];
             wita::keyboard_state(&mut ks);
             dbg!(wita::get_key_state(wita::VirtualKey::Char('A')));
